==> plasma-workspace-5.27.9.1.tar.xz: plasma-workspace-5.27.9.1/login-sessions/plasmax11.desktop.cmake <==
[Desktop Entry]
Type=XSession
Exec=${CMAKE_INSTALL_FULL_BINDIR}/startplasma-x11
TryExec=${CMAKE_INSTALL_FULL_BINDIR}/startplasma-x11
DesktopNames=KDE
Name=Plasma (X11)
Name[ar]=بلازما (اكس11)
Name[az]=Plasma (X11)
Name[be]=Plasma (X11)
Name[bg]=Plasma (X11)
Name[ca]=Plasma (X11)
Name[ca@valencia]=Plasma (X11)
Name[cs]=Plasma (X11)
Name[da]=Plasma (X11)
Name[de]=Plasma (X11)
Name[en_GB]=Plasma (X11)
Name[eo]=Plasma (X11)
Name[es]=Plasma (X11)
Name[eu]=Plasma (X11)
Name[fi]=Plasma (X11)
Name[fr]=Plasma (X11)
Name[gl]=Plasma (X11)
Name[hi]=प्लाज़्मा (एक्स ११)
Name[hu]=Plasma (X11)
Name[ia]=Plasma (X11)
Name[id]=Plasma (X11)
Name[is]=Plasma (X11)
Name[it]=Plasma (X11)
Name[ja]=Plasma (X11)
Name[ka]=Plasma (X11)
Name[ko]=Plasma(X11)
Name[lt]=Plasma (X11)
Name[ml]=പ്ലാസ്മ (X11)
Name[nl]=Plasma (X11)
Name[nn]=Plasma (X11)
Name[pa]=ਪਲਾਜ਼ਮਾ (X11)
Name[pl]=Plazma (X11)
Name[pt]=Plasma (X11)
Name[pt_BR]=Plasma (X11)
Name[ro]=Plasma (X11)
Name[ru]=Plasma (X11)
Name[sk]=Plasma (X11)
Name[sl]=Plasma (X11)
Name[sv]=Plasma (X11)
Name[ta]=பிளாஸ்மா (X11)
Name[tg]=Плазма (X11)
Name[tr]=Plasma (X11)
Name[uk]=Плазма (X11)
Name[vi]=Plasma (X11)
Name[x-test]=xxPlasma (X11)xx
Name[zh_CN]=Plasma (X11)
Name[zh_TW]=Plasma (X11)
Comment=Plasma by KDE
Comment[ar]=بلازما كِيدِي
Comment[az]=KDE Plasma
Comment[be]=Plasma KDE
Comment[bg]=Plasma от KDE
Comment[bs]=Plazma od strane KDe
Comment[ca]=Plasma, creat per la comunitat KDE
Comment[ca@valencia]=Plasma, creat per la comunitat KDE
Comment[cs]=Plasma z KDE
Comment[da]=Plasma fra KDE
Comment[de]=Plasma von KDE
Comment[el]=Plasma από το KDE
Comment[en_GB]=Plasma by KDE
Comment[es]=Plasma, por KDE
Comment[et]=KDE Plasma
Comment[eu]=KDEren Plasma
Comment[fi]=Plasma KDE:ltä
Comment[fr]=Plasma, par KDE
Comment[gl]=Plasma, fornecido por KDE.
Comment[he]=פלזמה באמצעות KDE
Comment[hi]=केडीइ द्वारा प्लाज़्मा
Comment[hsb]=Plasma wot KDE
Comment[hu]=Plasma a KDE-től
Comment[ia]=Plasma per KDE
Comment[id]=Plasma oleh KDE
Comment[is]=Plasma frá KDE
Comment[it]=Plasma di KDE
Comment[ja]=Plasma by KDE
Comment[ka]=Plasma, KDE-სგან
Comment[ko]=KDE Plasma
Comment[lt]=Plasma pagal KDE
Comment[ml]=കെഡിഇയുടെ പ്ലാസ്മ
Comment[nb]=Plasma av KDE
Comment[nds]=Plasma vun KDE
Comment[nl]=Plasma door KDE
Comment[nn]=Plasma frå KDE
Comment[pa]=KDE ਵਲੋਂ ਪਲਾਜ਼ਮਾ
Comment[pl]=Plazma dzięki KDE
Comment[pt]=Plasma do KDE
Comment[pt_BR]=Plasma do KDE
Comment[ro]=Plasma, de către KDE
Comment[ru]=KDE Plasma
Comment[sk]=Plasma od KDE
Comment[sl]=KDE Plasma
Comment[sr]=Плазма од КДЕ‑а
Comment[sr@ijekavian]=Плазма од КДЕ‑а
Comment[sr@ijekavianlatin]=Plasma od KDE‑a
Comment[sr@latin]=Plasma od KDE‑a
Comment[sv]=Plasma av KDE
Comment[ta]=கே.டீ.யீ. வழங்கும் பிளாஸ்மா
Comment[tg]=Plasma аз ҷониби KDE
Comment[tr]=KDE Plasma
Comment[uk]=Плазма KDE
Comment[vi]=Plasma, do KDE
Comment[x-test]=xxPlasma by KDExx
Comment[zh_CN]=KDE Plasma
Comment[zh_TW]=Plasma by KDE
X-KDE-PluginInfo-Version=${PROJECT_VERSION}

==> plasma-workspace-6.0.1.tar.xz: plasma-workspace-6.0.1/login-sessions/plasmax11.desktop.cmake <==
[Desktop Entry]
Type=XSession
Exec=${CMAKE_INSTALL_FULL_BINDIR}/startplasma-x11
TryExec=${CMAKE_INSTALL_FULL_BINDIR}/startplasma-x11
DesktopNames=KDE
Name=Plasma (X11)
Name[ar]=بلازما (اكس11)
Name[ast]=Plasma (X11)
Name[az]=Plasma (X11)
Name[be]=Plasma (X11)
Name[bg]=Plasma (X11)
Name[ca]=Plasma (X11)
Name[ca@valencia]=Plasma (X11)
Name[cs]=Plasma (X11)
Name[da]=Plasma (X11)
Name[de]=Plasma (X11)
Name[en_GB]=Plasma (X11)
Name[eo]=Plasma (X11)
Name[es]=Plasma (X11)
Name[eu]=Plasma (X11)
Name[fi]=Plasma (X11)
Name[fr]=Plasma (X11)
Name[gl]=Plasma (X11)
Name[he]=פלזמה (X11)
Name[hi]=प्लाज़्मा (एक्स ११)
Name[hu]=Plasma (X11)
Name[ia]=Plasma (X11)
Name[id]=Plasma (X11)
Name[is]=Plasma (X11)
Name[it]=Plasma (X11)
Name[ja]=Plasma (X11)
Name[ka]=Plasma (X11)
Name[ko]=Plasma(X11)
Name[lt]=Plasma (X11)
Name[ml]=പ്ലാസ്മ (X11)
Name[nl]=Plasma (X11)
Name[nn]=Plasma (X11)
Name[pa]=ਪਲਾਜ਼ਮਾ (X11)
Name[pl]=Plazma (X11)
Name[pt]=Plasma (X11)
Name[pt_BR]=Plasma (X11)
Name[ro]=Plasma (X11)
Name[ru]=Plasma (X11)
Name[sa]=प्लाज्मा (X११)
Name[sk]=Plasma (X11)
Name[sl]=Plasma (X11)
Name[sv]=Plasma (X11)
Name[ta]=பிளாஸ்மா (X11)
Name[tg]=Плазма (X11)
Name[tr]=Plasma (X11)
Name[uk]=Плазма (X11)
Name[vi]=Plasma (X11)
Name[x-test]=xxPlasma (X11)xx
Name[zh_CN]=Plasma (X11)
Name[zh_TW]=Plasma (X11)
Comment=Plasma by KDE
Comment[ar]=بلازما كِيدِي
Comment[az]=KDE Plasma
Comment[be]=Plasma KDE
Comment[bg]=Plasma от KDE
Comment[bs]=Plazma od strane KDe
Comment[ca]=Plasma, creat per la comunitat KDE
Comment[ca@valencia]=Plasma, creat per la comunitat KDE
Comment[cs]=Plasma z KDE
Comment[da]=Plasma fra KDE
Comment[de]=Plasma von KDE
Comment[el]=Plasma από το KDE
Comment[en_GB]=Plasma by KDE
Comment[eo]=Plasma de KDE
Comment[es]=Plasma, por KDE
Comment[et]=KDE Plasma
Comment[eu]=KDEren Plasma
Comment[fi]=Plasma KDE:ltä
Comment[fr]=Plasma, par KDE
Comment[gl]=Plasma, fornecido por KDE.
Comment[he]=פלזמה מבית KDE
Comment[hi]=केडीइ द्वारा प्लाज़्मा
Comment[hsb]=Plasma wot KDE
Comment[hu]=Plasma a KDE-től
Comment[ia]=Plasma per KDE
Comment[id]=Plasma oleh KDE
Comment[is]=Plasma frá KDE
Comment[it]=Plasma di KDE
Comment[ja]=Plasma by KDE
Comment[ka]=Plasma, KDE-სგან
Comment[ko]=KDE Plasma
Comment[lt]=Plasma pagal KDE
Comment[ml]=കെഡിഇയുടെ പ്ലാസ്മ
Comment[nb]=Plasma av KDE
Comment[nds]=Plasma vun KDE
Comment[nl]=Plasma door KDE
Comment[nn]=Plasma frå KDE
Comment[pa]=KDE ਵਲੋਂ ਪਲਾਜ਼ਮਾ
Comment[pl]=Plazma dzięki KDE
Comment[pt]=Plasma do KDE
Comment[pt_BR]=Plasma do KDE
Comment[ro]=Plasma, de către KDE
Comment[ru]=KDE Plasma
Comment[sa]=KDE इत्यस्मात् प्लाज्मा
Comment[sk]=Plasma od KDE
Comment[sl]=KDE Plasma
Comment[sr]=Плазма од КДЕ‑а
Comment[sr@ijekavian]=Плазма од КДЕ‑а
Comment[sr@ijekavianlatin]=Plasma od KDE‑a
Comment[sr@latin]=Plasma od KDE‑a
Comment[sv]=Plasma av KDE
Comment[ta]=கே.டீ.யீ. வழங்கும் பிளாஸ்மா
Comment[tg]=Plasma аз ҷониби KDE
Comment[tr]=KDE Plasma
Comment[uk]=Плазма KDE
Comment[vi]=Plasma, do KDE
Comment[x-test]=xxPlasma by KDExx
Comment[zh_CN]=KDE Plasma
Comment[zh_TW]=Plasma by KDE
X-KDE-PluginInfo-Version=${PROJECT_VERSION}
